@@ -4,6 +4,9 @@ use strict;
 use warnings;
 use DynaLoader;
 
+# Make sure debugging with Data::Dumper is more easily comparable:
+$Data::Dumper::Sortkeys = 1;
+
 # different files, but same package
 # require them here to avoid dependencies
 use URPM::Build;
@@ -11,7 +14,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '5.15.2';
+our $VERSION = 'v5.26.1';
 
 URPM->bootstrap($VERSION);
 
@@ -837,6 +840,11 @@ Options are:
     update => 0 / 1 : indicates whether this is an upgrade
     excludepath => [ ... ]
 
+=item $trans->addReinstall($pkg)
+
+Adds a package to be re-installed to the transaction represented by $trans.
+$pkg is an C<URPM::Package> object.
+
 =item $trans->remove($name)
 
 Adds a package to be erased to the transaction represented by $trans.
@@ -874,6 +882,7 @@ Recognized options are:
     callback_open   => sub { ... }
     callback_trans  => sub { ... }
     callback_uninst => sub { ... }
+    callback_verify => sub { ... }
     delta => used for progress callbacks (trans, uninst, inst)
     excludedocs => 0 / 1
     force => 0 / 1
@@ -886,13 +895,13 @@ Recognized options are:
 
 They roughly correspond to command-line options to rpm(1).
 
-'callback_open' signature is (C<$data>, C<$cb_type>, C<$pkg_id>, C<pkg_name>). It _must_ return a file handler for the asked package.
+'callback_open' signature is (C<$data>, C<$cb_type>, C<$pkg_id>). It _must_ return a file handler for the asked package.
 
-'callback_close' signature is (C<$data>, C<$cb_type>, C<$pkg_id>, C<pkg_name>). It is called just before URPM close the fd for the installed package.
+'callback_close' signature is (C<$data>, C<$cb_type>, C<$pkg_id>). It is called just before URPM close the fd for the installed package.
 
 C<$cb_type> is one of 'open' or 'close'.
 
-Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>, C<pkg_name>)
+Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>)
 
 C<$cb_type> is one of 'elem', 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
 For 'error', it can be 'cpio', 'script' or 'unpack'.
@@ -1043,6 +1052,8 @@ B<transaction_state>: $state object
 
 The L<URPM::Resolve> implements the resolving bits.
 
+The L<URPM::Signature> implements the pubkey bits.
+
 The L<urpm> package is a higher level module used by the urpmi command line tool,
 the rpmdrake GUI and the drakx installer.
 
